==> hyades.source_3.0.2_20050225_1641.zip: org/eclipse/hyades/test/ui/launch/configurations/AbstractLaunchConfigurationFacade.java <==
/*******************************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.test.ui.launch.configurations;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.eclipse.core.internal.runtime.Assert;
import org.eclipse.core.resources.IContainer;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.debug.core.ILaunchConfiguration;
import org.eclipse.debug.core.ILaunchConfigurationWorkingCopy;
import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.emf.ecore.resource.ResourceSet;
import org.eclipse.hyades.test.ui.TestUIPlugin;
import org.eclipse.hyades.test.ui.internal.model.EMFUtil;

/**
 * This class provides common methods for Launch Configuration Facades.
 * A Launch Configuration Facade provides a set of helper methods for reading from
 * and writing to Launch Configurations.
 * @author jcanches
 */
public class AbstractLaunchConfigurationFacade {
	
	/**
	 * This prefix is used for all Hyades properties within a Launch Configuration.
	 */
	protected final static String PROPERTY_PREFIX = "org.eclipse.hyades.test.ui.launch"; //$NON-NLS-1$
	
	/**
	 * Store in the provided Launch Configuration Working Copy the reference to an  EMF Object.
	 * @param configuration The LaunchConfigurationWorkingCopy where the reference is stored.
	 * @param property The name of the property within the Launch Configuration that receives
	 * the reference.
	 * @param eObject The EMF Object. This object must belong to an EMF Resource.
	 */
    protected static void storeEMFReference(ILaunchConfigurationWorkingCopy configuration, String property, EObject eObject) {
        String uri;
        String uriFragment;
        
        if (eObject == null) {
            uri = ""; //$NON-NLS-1$
            uriFragment = ""; //$NON-NLS-1$
        } else {
        	Assert.isNotNull(eObject.eResource());
            uri = eObject.eResource().getURI().toString();
            uriFragment = eObject.eResource().getURIFragment(eObject);
        }
        configuration.setAttribute(property + "URI", uri); //$NON-NLS-1$
        configuration.setAttribute(property + "URIFragment", uriFragment); //$NON-NLS-1$
    }
    
	/**
	 * Retrieves from the provided Launch Configuration Working Copy an EMF Object.
	 * @param configuration The LaunchConfigurationWorkingCopy to load from.
	 * @param property The name of the property within the Launch Configuration that contains EMF Object.
	 * @return The EMF Object (or null if the reference could not be resolved)
	 */
    protected static EObject resolveEMFReference(ILaunchConfiguration configuration, String property) throws CoreException {
        String uriString = configuration.getAttribute(property + "URI", (String)null); //$NON-NLS-1$
        String uriFragment = configuration.getAttribute(property + "URIFragment", (String)null); //$NON-NLS-1$
        if (uriString == null || uriString.equals("")) { //$NON-NLS-1$
        	return null;
        }
        URI uri = URI.createURI(uriString);
        Resource res = getResource(uri);
        if (res == null) {
        	return null;
        }
        return res.getEObject(uriFragment);
    }

	/**
	 * Store in the provided Launch Configuration Working Copy the reference to a set of
	 * EMF Objects.
	 * @param configuration The LaunchConfigurationWorkingCopy where the reference is stored.
	 * @param property The name of the property within the Launch Configuration that receives
	 * the reference.
	 * @param list The list of EMF Objects (subclasses of EObject). These objects must belong to
	 * an EMF Resource.
	 */
    protected static void storeEMFReferences(ILaunchConfigurationWorkingCopy configuration, String property, List list) {
        List uriList = new ArrayList();
        List uriFragmentList = new ArrayList();
        for (Iterator it = list.iterator(); it.hasNext();) {
            Object obj = it.next();
            if (obj instanceof EObject) {
                EObject eObject = (EObject) obj;
                if (eObject == null) {
                    uriList.add(""); //$NON-NLS-1$
                    uriFragmentList.add(""); //$NON-NLS-1$
                } else {
                	Assert.isNotNull(eObject.eResource());
                    uriList.add(eObject.eResource().getURI().toString());
                    uriFragmentList.add(eObject.eResource().getURIFragment(eObject));
                }
            }
        }
        configuration.setAttribute(property + "URI", uriList); //$NON-NLS-1$
        configuration.setAttribute(property + "URIFragment", uriFragmentList); //$NON-NLS-1$
    }

	/**
	 * Retrieves from the provided Launch Configuration Working Copy a set of EMF Object.
	 * @param configuration The LaunchConfigurationWorkingCopy to load from.
	 * @param property The name of the property within the Launch Configuration that contains the
	 * set of EMF Objects.
	 * @return The list of EMF Objects (subclasses of EObject).
	 */
    protected static List resolveEMFReferences(ILaunchConfiguration configuration, String property) throws CoreException {
        List ret = new ArrayList();
        List uriList = configuration.getAttribute(property + "URI", new ArrayList()); //$NON-NLS-1$
        List uriFragmentList = configuration.getAttribute(property + "URIFragment", new ArrayList()); //$NON-NLS-1$
        if (uriFragmentList.isEmpty() || uriList.isEmpty()) { return new ArrayList(); }
        for (int i = 0, max = uriList.size(); i < max; ++i) {
        	String uriString = (String)uriList.get(i);
        	if (uriString != null && !uriString.equals("")) { //$NON-NLS-1$
		        URI uri = URI.createURI((String) uriList.get(i));
		        Resource res = getResource(uri);
		        if (res != null) {
		            EObject obj = res.getEObject((String) uriFragmentList.get(i));
		        	if (obj != null) {
		        		ret.add(obj);
		        	}
		        }
        	}
        }
        return ret;
    }
    
    /**
     * Retrieves from the supplied Launch Configuration a container property.
     * @param configuration
     * @param property
     * @return A Workspace Container. This resource always exists.
     * @throws CoreException
     */
    protected static IContainer getContainerProperty(ILaunchConfiguration configuration, String property) throws CoreException {
		String location = configuration.getAttribute(property, (String)null);
		if (location != null) {
			IResource res = ResourcesPlugin.getWorkspace().getRoot().findMember(location);
			if (res != null && res instanceof IContainer) {
				return (IContainer)res;
			}
		}
		return null;
    }
    
    /**
     * Store in the supplied Launch Configuration a container property.
     * @param configuration
     * @param property
     * @param value
     */
    protected static void setContainerProperty(ILaunchConfigurationWorkingCopy configuration, String property, IContainer value) {
    	String container = null;
    	if (value != null) {
    		container = value.getFullPath().toString();
    	}
    	configuration.setAttribute(property, container);
    }

    private static Resource getResource(URI uri) {
    	// Use the TestUI shared Resource Set
		ResourceSet resourceSet = EMFUtil.getResourceSet();
		try {
			return resourceSet.getResource(uri, /*loadOnDemand*/true);
		} catch (Throwable t) {
			TestUIPlugin.logError(t);
			return null;
		}
     }

}

==> hyades.source_3.1.0_20041019_1201.zip: org/eclipse/hyades/test/ui/launch/configurations/AbstractLaunchConfigurationFacade.java <==
/*******************************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.test.ui.launch.configurations;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.eclipse.core.internal.runtime.Assert;
import org.eclipse.core.resources.IContainer;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.debug.core.ILaunchConfiguration;
import org.eclipse.debug.core.ILaunchConfigurationWorkingCopy;
import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.emf.ecore.resource.ResourceSet;
import org.eclipse.hyades.test.ui.TestUIPlugin;
import org.eclipse.hyades.test.ui.internal.model.EMFUtil;

/**
 * This class provides common methods for Launch Configuration Facades.
 * A Launch Configuration Facade provides a set of helper methods for reading from
 * and writing to Launch Configurations.
 * @author jcanches
 */
public class AbstractLaunchConfigurationFacade {
	
	/**
	 * This prefix is used for all Hyades properties within a Launch Configuration.
	 */
	protected final static String PROPERTY_PREFIX = "org.eclipse.hyades.test.ui.launch"; //$NON-NLS-1$
	
	/**
	 * Store in the provided Launch Configuration Working Copy the reference to an  EMF Object.
	 * @param configuration The LaunchConfigurationWorkingCopy where the reference is stored.
	 * @param property The name of the property within the Launch Configuration that receives
	 * the reference.
	 * @param eObject The EMF Object. This object must belong to an EMF Resource.
	 */
    protected static void storeEMFReference(ILaunchConfigurationWorkingCopy configuration, String property, EObject eObject) {
        String uri;
        String uriFragment;
        
        if (eObject == null) {
            uri = ""; //$NON-NLS-1$
            uriFragment = ""; //$NON-NLS-1$
        } else {
        	Assert.isNotNull(eObject.eResource());
            uri = eObject.eResource().getURI().toString();
            uriFragment = eObject.eResource().getURIFragment(eObject);
        }
        configuration.setAttribute(property + "URI", uri); //$NON-NLS-1$
        configuration.setAttribute(property + "URIFragment", uriFragment); //$NON-NLS-1$
    }
    
	/**
	 * Retrieves from the provided Launch Configuration Working Copy an EMF Object.
	 * @param configuration The LaunchConfigurationWorkingCopy to load from.
	 * @param property The name of the property within the Launch Configuration that contains EMF Object.
	 * @return The EMF Object (or null if the reference could not be resolved)
	 * @deprecated
	 * @see AbstractLaunchConfigurationFacade#resolveEMFReference(ILaunchConfiguration, String, ResourceSet)
	 */
    protected static EObject resolveEMFReference(ILaunchConfiguration configuration, String property) throws CoreException {
    	return resolveEMFReference(configuration, property, EMFUtil.getResourceSet());
    }

	/**
	 * Retrieves from the provided Launch Configuration Working Copy an EMF Object.
	 * @param configuration The LaunchConfigurationWorkingCopy to load from.
	 * @param property The name of the property within the Launch Configuration that contains EMF Object.
	 * @param resourceSet The Resource Set that should contain the returned object.
	 * @return The EMF Object (or null if the reference could not be resolved)
	 * @since 3.1
	 */
    protected static EObject resolveEMFReference(ILaunchConfiguration configuration, String property, ResourceSet resourceSet) throws CoreException {
        String uriString = configuration.getAttribute(property + "URI", (String)null); //$NON-NLS-1$
        String uriFragment = configuration.getAttribute(property + "URIFragment", (String)null); //$NON-NLS-1$
        if (uriString == null || uriString.equals("")) { //$NON-NLS-1$
        	return null;
        }
        URI uri = URI.createURI(uriString);
        try {
	        Resource res = resourceSet.getResource(uri, /*loadOnDemand*/true);
	        if (res == null) {
	        	return null;
	        }
	        return res.getEObject(uriFragment);
        } catch (Throwable t) {
        	// This may happen if some artifacts referenced by the configuration
        	// have been deleted. Failing to resolve just returns null.
        	TestUIPlugin.logError(t);
        	return null;
        }
    }

	/**
	 * Store in the provided Launch Configuration Working Copy the reference to a set of
	 * EMF Objects.
	 * @param configuration The LaunchConfigurationWorkingCopy where the reference is stored.
	 * @param property The name of the property within the Launch Configuration that receives
	 * the reference.
	 * @param list The list of EMF Objects (subclasses of EObject). These objects must belong to
	 * an EMF Resource.
	 */
    protected static void storeEMFReferences(ILaunchConfigurationWorkingCopy configuration, String property, List list) {
        List uriList = new ArrayList();
        List uriFragmentList = new ArrayList();
        for (Iterator it = list.iterator(); it.hasNext();) {
            Object obj = it.next();
            if (obj instanceof EObject) {
                EObject eObject = (EObject) obj;
                if (eObject == null) {
                    uriList.add(""); //$NON-NLS-1$
                    uriFragmentList.add(""); //$NON-NLS-1$
                } else {
                	Assert.isNotNull(eObject.eResource());
                    uriList.add(eObject.eResource().getURI().toString());
                    uriFragmentList.add(eObject.eResource().getURIFragment(eObject));
                }
            }
        }
        configuration.setAttribute(property + "URI", uriList); //$NON-NLS-1$
        configuration.setAttribute(property + "URIFragment", uriFragmentList); //$NON-NLS-1$
    }

	/**
	 * Retrieves from the provided Launch Configuration Working Copy a set of EMF Object.
	 * @param configuration The LaunchConfigurationWorkingCopy to load from.
	 * @param property The name of the property within the Launch Configuration that contains the
	 * set of EMF Objects.
	 * @return The list of EMF Objects (subclasses of EObject).
	 * @deprecated
	 */
    protected static List resolveEMFReferences(ILaunchConfiguration configuration, String property) throws CoreException {
    	return resolveEMFReferences(configuration, property, EMFUtil.getResourceSet());
    }
    
	/**
	 * Retrieves from the provided Launch Configuration Working Copy a set of EMF Object.
	 * @param configuration The LaunchConfigurationWorkingCopy to load from.
	 * @param property The name of the property within the Launch Configuration that contains the
	 * set of EMF Objects.
	 * @param resourceSet The Resource Set that should contain the returned objects.
	 * @return The list of EMF Objects (subclasses of EObject).
	 * @since 3.1
	 */
    protected static List resolveEMFReferences(ILaunchConfiguration configuration, String property, ResourceSet resourceSet) throws CoreException {
        List ret = new ArrayList();
        List uriList = configuration.getAttribute(property + "URI", new ArrayList()); //$NON-NLS-1$
        List uriFragmentList = configuration.getAttribute(property + "URIFragment", new ArrayList()); //$NON-NLS-1$
        if (uriFragmentList.isEmpty() || uriList.isEmpty()) { return new ArrayList(); }
        for (int i = 0, max = uriList.size(); i < max; ++i) {
        	String uriString = (String)uriList.get(i);
        	if (uriString != null && !uriString.equals("")) { //$NON-NLS-1$
		        URI uri = URI.createURI((String) uriList.get(i));
		        try {
			        Resource res = resourceSet.getResource(uri, /*loadOnDemand*/true);
			        if (res != null) {
			            EObject obj = res.getEObject((String) uriFragmentList.get(i));
			        	if (obj != null) {
			        		ret.add(obj);
			        	}
			        }
		        } catch (Throwable t) {
		        	// This may happen if some artifacts referenced by the configuration
		        	// have been deleted. Keep on resolving other elements.
		        	TestUIPlugin.logError(t);
		        }
        	}
        }
        return ret;
    }
    
    /**
     * Retrieves from the supplied Launch Configuration a container property.
     * @param configuration
     * @param property
     * @return A Workspace Container. This resource always exists.
     * @throws CoreException
     */
    protected static IContainer getContainerProperty(ILaunchConfiguration configuration, String property) throws CoreException {
		String location = configuration.getAttribute(property, (String)null);
		if (location != null) {
			IResource res = ResourcesPlugin.getWorkspace().getRoot().findMember(location);
			if (res != null && res instanceof IContainer) {
				return (IContainer)res;
			}
		}
		return null;
    }
    
    /**
     * Store in the supplied Launch Configuration a container property.
     * @param configuration
     * @param property
     * @param value
     */
    protected static void setContainerProperty(ILaunchConfigurationWorkingCopy configuration, String property, IContainer value) {
    	String container = null;
    	if (value != null) {
    		container = value.getFullPath().toString();
    	}
    	configuration.setAttribute(property, container);
    }

}
